@@ -1,20 +1,18 @@
+"""The kafka plugin of the Minos Framework."""
+
 __author__ = "Minos Framework Devs"
 __email__ = "hey@minos.run"
-__version__ = "0.6.1"
+__version__ = "0.7.0"
 
 from .common import (
     KafkaBrokerBuilderMixin,
     KafkaCircuitBreakerMixin,
 )
 from .publisher import (
-    InMemoryQueuedKafkaBrokerPublisher,
     KafkaBrokerPublisher,
     KafkaBrokerPublisherBuilder,
-    PostgreSqlQueuedKafkaBrokerPublisher,
 )
 from .subscriber import (
-    InMemoryQueuedKafkaBrokerSubscriberBuilder,
     KafkaBrokerSubscriber,
     KafkaBrokerSubscriberBuilder,
-    PostgreSqlQueuedKafkaBrokerSubscriberBuilder,
 )
